# Pyndamics3


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Install

`pip install pyndamics3`

## How to use

Some simple examples.

``` python
from pyndamics3 import Simulation
```

    pyndamics3  version  0.0.2

``` python
sim=Simulation()
sim.add("p'=a*p*(1-p/K)",1,plot=True)
sim.params(a=1,K=50)
sim.run(50)
```

![](index_files/figure-commonmark/cell-3-output-1.png)

    <Figure size 432x288 with 0 Axes>
